@@ -13,25 +13,25 @@
 #include "manager.h"
 #include "types.h"
 
+#include <memory>
+
 class NoInputNoOutputAgent : public BluezQt::Agent
 {
     Q_OBJECT
 
 public:
-    /**
+    /*
      * Creates a new NoInputNoOutputAgent object.
-     *
-     * @param parent
      */
     explicit NoInputNoOutputAgent(const QStringList &uuids, QObject *parent = nullptr);
 
-    /**
-      * Destroys a NoInputNoOutputAgent object.
-      */
+    /*
+     * Destroys a NoInputNoOutputAgent object.
+     */
     ~NoInputNoOutputAgent() override;
 
 Q_SIGNALS:
-    /**
+    /*
      * Indicates that a service was authorized.
      */
     void serviceAuthorized(BluezQt::DevicePtr device, const QString &uuid, bool allowed);
@@ -41,7 +41,7 @@ private:
     Capability capability() const override;
     void authorizeService(BluezQt::DevicePtr device, const QString &uuid, const BluezQt::Request<> &request) override;
 
-    class NoInputNoOutputAgentPrivate *const d;
+    std::unique_ptr<class NoInputNoOutputAgentPrivate> const d;
 };
 
 class MediaEndpointConnector : public QObject
